In many countries, livestock movement data are
collected with the major objective to enable contact tracing during disease
outbreaks. Livestock movement data can also be of relevance for risk based
surveillance - both during outbreak or when investigating if a disease is
present in the population. However, the livestock movement databases are
not always structured in such a way that relevant information for contact
tracing or surveillance design is easily retrieved. EpiContactTrace uses
the network parameters in-degree, out-degree, ingoing contact-chain and
outgoing contact-chain, which are relevant for forward- and backward
contact-tracing respectively. The measures can also be used for identifying
herds with many contacts, which can be used in risk based disease
surveillance. Different time periods for ingoing and outgoing contacts can
be of interest in the contact tracing, based on possible window of
introduction, and this can be adjusted in the tool. The output from the
analysis is available as a dataset, but moreover, the tool automatically
generates a report on farm level. The report both contains an overview of
the situation on the farm, including a graph, as well as detailed
information including dates of movements on group or individual level on
all contacts.