Learn R Programming

EpiContactTrace (version 0.9.1)

show-methods: Show

Description

Shows information of the time-window used for contact tracing and summary of network parameters. It also visualize the contact structure.

Usage

"show"(object)

Arguments

object
The Contacts or ContactTrace object

Value

None (invisible 'NULL').

Methods

signature(object = "Contacts")
Show information for the Contacts object.
signature(object = "ContactTrace")
Show information for the ingoing and outgoing Contacts of a ContactTrace object.

References

  • Dube, C., et al., A review of network analysis terminology and its application to foot-and-mouth disease modelling and policy development. Transbound Emerg Dis 56 (2009) 73-85, doi: 10.1111/j.1865-1682.2008.01064.x

  • Noremark, M., et al., Network analysis of cattle and pig movements in Sweden: Measures relevant for disease control and riskbased surveillance. Preventive Veterinary Medicine 99 (2011) 78-90, doi: 10.1016/j.prevetmed.2010.12.009

Examples

Run this code
## Not run: 
# 
# ## Load data
# data(transfers)
# 
# ## Perform contact tracing
# contactTrace <- Trace(movements=transfers,
#                       root=2645,
#                       tEnd='2005-10-31',
#                       days=90)
# 
# show(contactTrace)
# ## End(Not run)

Run the code above in your browser using DataLab