Learn R Programming

EpiContactTrace (version 0.9.1)

transfers: Movement Example Data

Description

Movement data included in the package. The data contains fictitious example data of cattle movements during the period 2005-08-01 -- 2005-10-31.

Usage

data(transfers)

Arguments

Format

A data frame with 70190 observations on the following 6 variables.
source
a numeric vector with the holding identifier of the source
destination
a numeric vector with holding identifier of the destination.
id
a character vector with the identity of the animal. In this dataset an 5 character hexadecimal vector.
t
a Date of the transfers
n
a numeric vector with the number of animals moved. Always 1 in this dataset.
category
a factor describing the category of the animal. Always Cattle in this dataset.

Examples

Run this code
## Not run: 
# data(transfers)
# 
# contactTrace <- Trace(movements=transfers,
#                       root=2645,
#                       tEnd='2005-10-31',
#                       days=90)
# 
# show(contactTrace)
# ## End(Not run)

Run the code above in your browser using DataLab